/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "XPathException.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomXPathException.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomXPathException.h"
#include "gdom/PrivateIntGdomXPathException.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::XPathException* obj)
{
    return WebCore::cacheDOMObject<WebCore::XPathException, GDOMXPathException>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMXPathException::GDOMXPathException(PassRefPtr<WebCore::XPathException> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMXPathException::~GDOMXPathException()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

gchar *
gdom_x_path_exception_to_string (GdomXPathException *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::XPathException * item = (gdom_x_path_exception_get_private(thiz));
    g_return_val_if_fail (item, 0);
    gchar * res = _G_GET_UTF8(item->toString());
    return res;

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "XPathException.h"
#include <gdom/GdomXPathException.h>
#include <gdom/PrivateGdomXPathException.h>
#include <gdom/PrivateIntGdomXPathException.h>
#include <gdom/GdomXPathExceptionprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomXPathException, gdom_x_path_exception, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomXPathExceptionPrivate {
    class WebCore::XPathException *item;
};

#define GDOM_X_PATH_EXCEPTION_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_X_PATH_EXCEPTION, GdomXPathExceptionPrivate))
*/
G_END_DECLS
WebCore::XPathException *
gdom_x_path_exception_get_private(GdomXPathException *request)
{
    GDOMXPathException *res;
    res = static_cast<GDOMXPathException*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::XPathException*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_CODE,
    PROP_NAME,
    PROP_MESSAGE,
};


static void gdom_x_path_exception_finalize(GObject* object)
{
    /*GdomXPathException* request = GDOM_X_PATH_EXCEPTION(object);*/
    /*GdomXPathExceptionPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_x_path_exception_parent_class)->finalize(object);
}

static void gdom_x_path_exception__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomXPathException *self = GDOM_X_PATH_EXCEPTION(object);
    WebCore::XPathException * gself = (gdom_x_path_exception_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_x_path_exception__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomXPathException *self = GDOM_X_PATH_EXCEPTION(object);
    WebCore::XPathException * gself = (gdom_x_path_exception_get_private(self));
    switch (prop_id) {
    case PROP_CODE:
    {
         g_value_set_uint (value, gself->code());
         break;
    }
    case PROP_NAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->name()));
         break;
    }
    case PROP_MESSAGE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->message()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_x_path_exception_class_init(GdomXPathExceptionClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_x_path_exception_finalize;
    g_klass->set_property = gdom_x_path_exception__set_property_fn;
    g_klass->get_property = gdom_x_path_exception__get_property_fn;

    g_object_class_install_property (g_klass, PROP_CODE,
            g_param_spec_uint ("code", /* name */
                "x_path_exception_code", /* short description */
                "read-only  gushort XPathException.code", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXUINT16, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_NAME,
            g_param_spec_string ("name", /* name */
                "x_path_exception_name", /* short description */
                "read-only  gchar * XPathException.name", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_MESSAGE,
            g_param_spec_string ("message", /* name */
                "x_path_exception_message", /* short description */
                "read-only  gchar * XPathException.message", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomXPathExceptionPrivate));*/
}

static void gdom_x_path_exception_init(GdomXPathException* request)
{
    /*GdomXPathExceptionPrivate* priv = GDOM_X_PATH_EXCEPTION_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

